@@ -360,7 +360,7 @@ if (sizeof($email_list)) {
      # Warn("Omitting invalid one: $email");
     }
     $user["systemvalues"]["email"] = parsePlaceHolders($system_values["email"],array_merge($replace,$system_values,array("number" => $c)));
-    $user["systemvalues"]["email"] = clean($user["systemvalues"]["email"]);
+    $user["systemvalues"]["email"] = cleanEmail($user["systemvalues"]["email"]);
     $c++;
     if ($_SESSION["test_import"]) {
      # print "<br/><b>$index</b><br/>";
@@ -576,7 +576,7 @@ if (sizeof($email_list)) {
           $count["list_add"]++;
         if (!TEST && $_SESSION["notify"] == "yes" && $addition) {
           $subscribemessage = ereg_replace('\[LISTS\]', $listoflists, getUserConfig("subscribemessage",$userid));
-          sendMail($user["systemvalues"]["email"], getConfig("subscribesubject"), $subscribemessage,system_messageheaders(),$envelope);
+          sendMail($user["systemvalues"]["email"], getConfig("subscribesubject"), stripslashes($subscribemessage),system_messageheaders(),$envelope);
         }
       }
       if (!is_array($_SESSION["groups"])) {
