@@ -1,3 +1,3 @@
-<h1>Crie m&uacute;ltiplas p&aacute;ginas de inscri&ccedil;&atilde;o.</h1>
-<p>Esta p&aacute;gina permite que voc&ecirc; crie as p&aacute;ginas de inscri&ccedil;&atilde;o dos usu&acute;rios de suas listas.</p>
+<h3>Crie m&uacute;ltiplas p&aacute;ginas de inscri&ccedil;&atilde;o.</h3>
+<p>Esta p&aacute;gina permite que voc&ecirc; crie as p&aacute;ginas de inscri&ccedil;&atilde;o dos usu&aacute;rios de suas listas.</p>
 <p>Voc&ecirc; pode selecionar qualquer conjunto de atributos e listas definidas em seu sistema. Desde valores para atributos padr&atilde;o at&eacute; valores de atributos globais, mas voc&ecirc; pode reorden&aacute;-los e adicionar outros valores padr&aacute;o. Voc&ecirc; tamb&eacute;m pode alterar se um atributo deve ser obrigat&oacute;rio ou n&atilde;o. A obrigatoriedade de atributos s&oacute; ter&aacute; efeito quando o usu&aacute;rio usa uma p&aacute;gina para se conectar.</p>
