@@ -3,7 +3,7 @@ $lan = array(
   'SaveChanges' => 'Speichern',
   'NameNotEmpty' => 'Name darf nicht leer sein:',
   'NameNotUnique' => 'Name ist nicht eindeutig',
-  'ExistingAttr' => 'Bestehende Attribute:<p>',
+  'ExistingAttr' => 'Bestehende Attribute:',
   'NoAttrYet' => 'Es wurden noch keine Attribute definiert.<br /><br />',
   'Attribute' => 'Attribut ID ',
   'Delete' => 'L&ouml;schen',
