@@ -1,7 +1,7 @@
 <?php 
 $lan = array(
 
-  'subscribe pages' => 'ID',
+  'subscribe pages' => 'Anmeldeseiten',
   'deleted' => 'Gel&ouml;scht',
   'add_new' => 'Neue Anmeldeseite',
   'title' => 'Titel',
