@@ -65,9 +65,9 @@ $lan = array (
   'pdf' => 'PDF',
 //  'textandhtml' => 'Texto y HTML', //obsolete by bug 0009687
   'textandpdf' => 'Texto y PDF',
-  'usetemplate' => 'Utilizar patr&oacute;n',
+  'usetemplate' => 'Utilizar plantilla',
   'selectone' => 'escoja uno',
-  'rssintro' => 'Si quiere usar este mensaje como patr&oacute;n para
+  'rssintro' => 'Si quiere usar este mensaje como plantilla para
   enviar canales RSS escoja la frecuencia con la que se debe utilizar,
   e incluya [RSS] en su mensaje para indicar d&oacute;nde debe ir la
   lista de elementos.',
@@ -76,10 +76,9 @@ $lan = array (
   'expand' => 'expandir',
   'plaintextversion' => 'Versi&oacute; en texto plano del mensaje',
   'messagefooter' => 'Pie de mensaje',
-  'messagefooterexplanation' => 'Utilice <b>[UNSUBSCRIBE]</b> para incluir
-  una URL &uacute;nica para cada usuario, en la que se pueda desinscribir.
-    <br/>Utilice <b>[PREFERENCES]</b> para incluir una URL &uacute;nica
-  para cada usuario, en la que se pueda actualizar sus datos',
+  'messagefooterexplanation1' => 'Utilice <b>[UNSUBSCRIBE]</b> para incluir una URL &uacute;nica para cada usuario, en la que se pueda desinscribir.',
+  'messagefooterexplanation2' => 'Utilice <b>[PREFERENCES]</b> para incluir una URL &uacute;nica para cada usuario, en la que pueda actualizar sus datos',
+  'messagefooterexplanation3' => 'Utilice <b>[FORWARD]</b> para agregar una URL personalizada para reenviar el mensaje a otra persona.',
   'addattachments' => 'Adjuntar ficheros a su mensaje.',
   'uploadlimits' => 'El servidor ha establecido los siguientes
   l&iacute;mites en la carga de ficheros',
