@@ -3,6 +3,6 @@
 $lan = array(
   'Top 50 domains with more than 5 emails' => 'Os 50 sites com mais de 5 emails',
   'num' => 'num',
+  'perc' => '%',
 );
 ?>
-‾
\ No newline at end of file
