@@ -8,54 +8,41 @@ http://www.w3.org/International/O-charset-lang.html
 */
 
 $LANGUAGES = array(
-#"af" => array("Afrikaans","iso-8859-1, windows-1252"),
-#"sq" => array("Albanian","iso-8859-1, windows-1252"),
-#"ar" => array("Arabic","iso-8859-6"),
-#"eu" => array("Basque","iso-8859-1, windows-1252"),
-#"bg" => array("Bulgarian","iso-8859-5"),
-#"be" => array("Byelorussian","iso-8859-5"),
-#"ca" => array("Catalan","iso-8859-1, windows-1252"),
-#"hr" => array("Croatian"," iso-8859-2, windows-1250 "),
-#"cs" => array("Czech "," iso-8859-2 "),
-#"da" => array("Danish "," iso-8859-1, windows-1252 "),
-#"nl"=> array("Dutch "," iso-8859-1, windows-1252 "),
-#"eo" => array("Esperanto "," iso-8859-3* "),
-#"et" => array("Estonian ","iso-8859-15 "),
-#"fo" => array("Faroese "," iso-8859-1, windows-1252 "),
-#"fi"=> array("Finnish "," iso-8859-1, windows-1252 "),
+"nl"=> array("Dutch ","iso-8859-1"," iso-8859-1, windows-1252 "),
 "de" => array("Deutsch ","iso-8859-1","iso-8859-1, windows-1252 "),
 "en" => array("English ","iso-8859-1","iso-8859-1, windows-1252 "),
 "es"=>array("espa&ntilde;ol","iso-8859-1","iso-8859-1, windows-1252"),
+#"fa" => array('Persian','utf-8','utf-8'),
 "fr"=>array("fran&ccedil;ais ","iso-8859-1","iso-8859-1, windows-1252 "),
-#"gl"=>array("Galician "," iso-8859-1, windows-1252 "),
-#"el"=> array("Greek "," iso-8859-7 "),
-#"he"=> array("Hebrew "," iso-8859-8 "),
-#"hu"=>array("Hungarian "," iso-8859-2 "),
-#"is"=>array("Icelandic "," iso-8859-1, windows-1252 "),
-#"ga"=>array("Irish "," iso-8859-1, windows-1252 "),
-#"it"=>array("Italian "," iso-8859-1, windows-1252 "),
-#"ja"=>array("Japanese ","EUC-JP"," shift_jis, iso-2022-jp, euc-jp"),
-#"lv"=> array("Latvian ","iso-8859-13, windows-1257"),
-#"lt"=> array("Lithuanian "," iso-8859-13, windows-1257"),
-#"mk"=> array("Macedonian ","iso-8859-5, windows-1251"),
-#"mt"=> array("Maltese ","iso-8859-3"),
-#"no"=>array("Norwegian ","iso-8859-1, windows-1252"),
-#"pl"=>array("Polish ","iso-8859-2"),
-#"pt"=>array("Portuguese "," iso-8859-1, windows-1252"),
+"pl"=>array("Polish ","iso-8859-2","iso-8859-2"),
 "pt-br"=>array("portugu&ecirc;s ","iso-8859-1","iso-8859-1, windows-1252"),
-#"ro"=>array("Romanian "," iso-8859-2"),
-#"ru"=>array("Russian "," koi8-r, iso-8859-5"),
-#"gd"=>array("Scottish "," iso-8859-1, windows-1252"),
-#"srcyrillic"=>array("Serbian "," windows-1251, iso-8859-5"),
-#"srlatin"=>array("Serbian "," iso-8859-2, windows-1250"),
-#"sk"=>array( "Slovak "," iso-8859-2"),
-#"sl"=>array( "Slovenian "," iso-8859-2, windows-1250"),
-#"sv"=>array("Swedish "," iso-8859-1, windows-1252"),
-#"tr"=> array("Turkish "," iso-8859-9, windows-1254"),
-#"uk"=>array("Ukrainian "," iso-8859-5"),
 "zh-tw" => array("Traditional Chinese","utf-8","utf-8"),
 );
 
+## pick up languages from the lan directory
+$landir = dirname(__FILE__).'/lan/';
+$d = opendir($landir);
+while ($lancode = readdir($d)) {
+#  print "<br/>".$dir;
+  if (!in_array($landir,array_keys($LANGUAGES)) && is_dir($landir.'/'.$lancode) && is_file($landir.'/'.$lancode.'/language_info')) {
+    $lan_info = file_get_contents($landir.'/'.$lancode.'/language_info');
+    $lines = explode("\n",$lan_info);
+    $lan = array();
+    foreach ($lines as $line) {
+      if (preg_match('/(\w+)=([\w -]+)/',$line,$regs)) {
+        $lan[$regs[1]] = $regs[2];
+      }
+    }
+    if (!empty($lan['name']) && !empty($lan['charset'])) {
+      $LANGUAGES[$lancode] = array($lan['name'],$lan['charset'],$lan['charset']);
+    }
+    
+#    print '<br/>'.$landir.'/'.$lancode;
+  }
+}
+ksort($LANGUAGES);
+#var_dump($LANGUAGES);
+
 if (!empty($GLOBALS["SessionTableName"])) {
   require_once dirname(__FILE__).'/sessionlib.php';
 }
@@ -105,9 +92,11 @@ if (!isset($_SESSION['adminlanguage']) || !is_array($_SESSION['adminlanguage']))
 ## this interferes with the frontend if an admin is logged in. 
 ## better split the frontend and backend charSets at some point
 ##http://mantis.tincan.co.uk/view.php?id=5528
-if (!isset($GLOBALS['strCharSet'])) {
+#if (!isset($GLOBALS['strCharSet'])) {
   $GLOBALS['strCharSet'] = $_SESSION['adminlanguage']['charset'];
-}
+#
+
+#print '<h1>'. $GLOBALS['strCharSet'].'</h1>';
 
 # internationalisation (I18N)
 class phplist_I18N {
@@ -174,7 +163,7 @@ class phplist_I18N {
 
   function get($text) {
     if (isset($_GET["page"]))
-      $page = $_GET["page"];
+      $page = basename($_GET["page"]);
     else
       $page = "home";
     
