@@ -54,6 +54,11 @@ class PHPMailer
      */
     var $ErrorInfo         = "";
 
+    /**
+     * Timestamp for 'Received:' hederline
+     */
+    var $sTimeStamp;
+    
     /**
      * Sets the From email address for the message.
      * @var string
@@ -329,6 +334,9 @@ class PHPMailer
         $this->ReplyTo[$cur][1] = $name;
     }
 
+    function AddTimeStamp($sTimeStamp) {
+      $this->sTimeStamp = $sTimeStamp;      
+    }
 
     /////////////////////////////////////////////////
     // MAIL SENDING METHODS
@@ -765,6 +773,9 @@ class PHPMailer
         $this->boundary[1] = "b1_" . $uniq_id;
         $this->boundary[2] = "b2_" . $uniq_id;
 
+        if (!empty($this->sTimeStamp)) {
+          $result .= $this->HeaderLine("Received", $this->sTimeStamp);
+        }
         $result .= $this->HeaderLine("Date", $this->RFCDate());
         if($this->Sender == "")
             $result .= $this->HeaderLine("Return-Path", trim($this->From));
@@ -1499,4 +1510,4 @@ class PHPMailer
     }
 }
 
-?>
\ No newline at end of file
+?>
