@@ -217,7 +217,7 @@ function finish ($flag,$message) {
   }
   if (!$nothingtodo)
     output($GLOBALS['I18N']->get('Finished this run'));
-  if (!TEST && !$nothingtodo)
+  if (!TEST && !$nothingtodo && SEND_QUEUE_PROCESSING_REPORT)
     sendReport($subject,$message);
 }
 
@@ -578,7 +578,7 @@ while ($message = Sql_fetch_array($messages)) {
           if ($rssfrequency == $message["rsstemplate"]) {
             # output("User matches message frequency");
             $rssitems = rssUserHasContent($userid,$messageid,$rssfrequency);
-            $cansend = sizeof($rssitems) && (sizeof($rssitems) > $rss_content_threshold);
+            $cansend = sizeof($rssitems) && (sizeof($rssitems) >= $rss_content_threshold);
 #            if (!$cansend)
 #              output("No content to send for this user ".sizeof($rssitems));
           } else {
@@ -684,7 +684,7 @@ while ($message = Sql_fetch_array($messages)) {
                unset($running_throttle_delay);
              }
            } elseif (MAILQUEUE_THROTTLE) {
-             sleep(MAILQUEUE_THROTTLE);
+             usleep(MAILQUEUE_THROTTLE * 1000000);
            } elseif (MAILQUEUE_BATCH_SIZE && MAILQUEUE_AUTOTHROTTLE && $sent > 10) {
              $totaltime = $GLOBALS['processqueue_timer']->elapsed(1);
              $msgperhour = (3600/$totaltime) * $sent;
@@ -767,7 +767,11 @@ while ($message = Sql_fetch_array($messages)) {
     }
     $totaltime = $GLOBALS['processqueue_timer']->elapsed(1);
     $msgperhour = (3600/$totaltime) * $sent;
-    $secpermsg = $totaltime / $sent;
+    if ($sent) {
+      $secpermsg = $totaltime / $sent;
+    } else {
+      $secpermsg = 0;
+    }
     $timeleft = ($num_users - $sent) * $secpermsg;
     $eta = date('D j M H:i',time()+$timeleft);
     setMessageData($messageid,'ETA',$eta);
