@@ -6,7 +6,7 @@ require_once dirname(__FILE__).'/accesscheck.php';
 if (PHPMAILER && is_file(dirname(__FILE__).'/phpmailer/class.phpmailer.php')) {
   # phplistmailer, extended of the popular phpmail class
   # this is still very experimental
-  include_once $GLOBALS["coderoot"] . "class.phplistmailer.php";
+  include_once dirname(__FILE__)."/class.phplistmailer.php";
 } else {
   if (USE_OUTLOOK_OPTIMIZED_HTML) {
     require_once dirname(__FILE__)."/class.html.mime.mail-outlookfix.inc";
@@ -19,11 +19,18 @@ if (!function_exists("output")) {
   function output($text) {
    }
 }
-
 function sendEmail ($messageid,$email,$hash,$htmlpref = 0,$rssitems = array(),$forwardedby = array()) {
   global $strThisLink,$PoweredByImage,$PoweredByText,$cached,$website;
   if ($email == "")
     return 0;
+  #0013076: different content when forwarding 'to a friend'
+  if (FORWARD_ALTERNATIVE_CONTENT) {
+    $forwardContent = sizeof( $forwardedby ) > 0;
+    $messagedata = loadMessageData($messageid);
+  } else {
+    $forwardContent = 0;
+  }
+
   if (empty($cached[$messageid])) {
     $domain = getConfig("domain");
     $message = Sql_query("select * from {$GLOBALS["tables"]["message"]} where id = $messageid");
@@ -58,15 +65,18 @@ function sendEmail ($messageid,$email,$hash,$htmlpref = 0,$rssitems = array(),$f
 
     $cached[$messageid]["fromname"] = trim($cached[$messageid]["fromname"]);
     $cached[$messageid]["to"] = $message["tofield"];
-    $cached[$messageid]["subject"] = $message["subject"];
+    #0013076: different content when forwarding 'to a friend'
+    $cached[$messageid]["subject"] = $forwardContent ? stripslashes($messagedata["forwardsubject"]) : $message["subject"];
     $cached[$messageid]["replyto"] =$message["replyto"];
-    $cached[$messageid]["content"] = $message["message"];
-    if (USE_MANUAL_TEXT_PART) {
+    #0013076: different content when forwarding 'to a friend'
+    $cached[$messageid]["content"] = $forwardContent ? stripslashes($messagedata["forwardmessage"]) : $message["message"];
+    if (USE_MANUAL_TEXT_PART && !$forwardContent) {
       $cached[$messageid]["textcontent"] = $message["textmessage"];
     } else {
       $cached[$messageid]["textcontent"] = '';
     }
-    $cached[$messageid]["footer"] = $message["footer"];
+    #0013076: different content when forwarding 'to a friend'
+    $cached[$messageid]["footer"] = $forwardContent ? stripslashes($messagedata["forwardfooter"]) : $message["footer"];
     $cached[$messageid]["htmlformatted"] = $message["htmlformatted"];
     $cached[$messageid]["sendformat"] = $message["sendformat"];
     if ($message["template"]) {
@@ -95,7 +105,14 @@ function sendEmail ($messageid,$email,$hash,$htmlpref = 0,$rssitems = array(),$f
 
   # erase any placeholders that were not found
 #  $msg = ereg_replace("\[[A-Z ]+\]","",$msg);
-  $user_att_values = getUserAttributeValues($email);
+
+#0011857: forward to friend, retain attributes
+  if ($hash == 'forwarded' && defined('KEEPFORWARDERATTRIBUTES') && KEEPFORWARDERATTRIBUTES) {
+    $user_att_values = getUserAttributeValues($forwardedby['email']);
+  } else {
+    $user_att_values = getUserAttributeValues($email);
+  } 
+  
   $userdata = Sql_Fetch_Assoc_Query(sprintf('select * from %s where email = "%s"',
     $GLOBALS["tables"]["user"],$email));
 
@@ -104,6 +121,20 @@ function sendEmail ($messageid,$email,$hash,$htmlpref = 0,$rssitems = array(),$f
   $text["unsubscribe"] = sprintf('%s%suid=%s',$url,$sep,$hash);
   $html["unsubscribeurl"] = sprintf('%s%suid=%s',$url,$sep,$hash);
   $text["unsubscribeurl"] = sprintf('%s%suid=%s',$url,$sep,$hash);
+
+  #0013076: Blacklisting posibility for unknown users
+  $url = getConfig("blacklisturl");$sep = ereg('\?',$url)?'&':'?';
+  $html["blacklist"] = sprintf('<a href="%s%semail=%s">%s</a>',$url,$sep,$email,$strThisLink);
+  $text["blacklist"] = sprintf('%s%semail=%s',$url,$sep,$email);
+  $html["blacklisturl"] = sprintf('%s%semail=%s',$url,$sep,$email);
+  $text["blacklisturl"] = sprintf('%s%semail=%s',$url,$sep,$email);
+
+  #0013076: Problem found during testing: message part must be parsed correctly as well.  
+  if ($forwardContent) {
+    $html["unsubscribe"] = $html["blacklist"];
+    $text["unsubscribe"] = $text["blacklist"];
+  }
+  
   $url = getConfig("subscribeurl");$sep = ereg('\?',$url)?'&':'?';
   $html["subscribe"] = sprintf('<a href="%s">%s</a>',$url,$strThisLink);
   $text["subscribe"] = sprintf('%s',$url);
@@ -115,7 +146,7 @@ function sendEmail ($messageid,$email,$hash,$htmlpref = 0,$rssitems = array(),$f
   $text["forward"] = sprintf('%s%suid=%s&mid=%d',$url,$sep,$hash,$messageid);
   $html["forwardurl"] = sprintf('%s%suid=%s&mid=%d',$url,$sep,$hash,$messageid);
   $text["forwardurl"] = $text["forward"];
-  $url = getConfig("public_baseurl");
+  $url = getConfig("forwardurl");
   # make sure there are no newlines, otherwise they get turned into <br/>s
   $html["forwardform"] = sprintf('<form method="get" action="%s" name="forwardform" class="forwardform"><input type=hidden name="uid" value="%s" /><input type=hidden name="mid" value="%d" /><input type=hidden name="p" value="forward" /><input type=text name="email" value="" class="forwardinput" /><input name="Send" type="submit" value="%s" class="forwardsubmit"/></form>',$url,$hash,$messageid,$GLOBALS['strForward']);
   $text["signature"] = "\n\n";
@@ -207,17 +238,19 @@ function sendEmail ($messageid,$email,$hash,$htmlpref = 0,$rssitems = array(),$f
   $textmessage = $textcontent;
 
 ## Parse placeholders
-  foreach (array("forwardform","forward","subscribe","preferences","unsubscribe","signature") as $item) {
+  #0013076: Blacklisting posibility for unknown users
+  foreach (array("forwardform","subscribe","preferences","unsubscribe", 'blacklist') as $item) { #BUGFIX 0015303, 1/2
     if (eregi('\['.$item.'\]',$htmlmessage,$regs)) {
       $htmlmessage = eregi_replace('\['.$item.'\]',$html[$item],$htmlmessage);
-      unset($html[$item]);
+//      unset($html[$item]); //ASK: Why was this done? It breaks placeholders in the footer
     }
     if (eregi('\['.$item.'\]',$textmessage,$regs)) {
       $textmessage = eregi_replace('\['.$item.'\]',$text[$item],$textmessage);
-      unset($text[$item]);
+//      unset($text[$item]);
     }
   }
-  foreach (array("forwardurl","subscribeurl","preferencesurl","unsubscribeurl") as $item) {
+  #0013076: Blacklisting posibility for unknown users
+  foreach (array("forward","forwardurl","subscribeurl","preferencesurl","unsubscribeurl",'blacklisturl') as $item) {
     if (eregi('\['.$item.'\]',$htmlmessage,$regs)) {
       $htmlmessage = eregi_replace('\['.$item.'\]',$html[$item],$htmlmessage);
     }
@@ -229,12 +262,15 @@ function sendEmail ($messageid,$email,$hash,$htmlpref = 0,$rssitems = array(),$f
     $text['footer'] = $cached[$messageid]["footer"];
     $html['footer'] = $cached[$messageid]["footer"];
   } else {
-    $text['footer'] = getConfig('forwardfooter');
+    #0013076: different content when forwarding 'to a friend'
+    if( FORWARD_ALTERNATIVE_CONTENT ) {
+      $text['footer'] = stripslashes($messagedata["forwardfooter"]);
+    } else {
+      $text['footer'] = getConfig('forwardfooter');
+    }
     $html['footer'] = $text['footer'];
   }
 
-  $text["footer"] = eregi_replace("\[UNSUBSCRIBE\]",$text["unsubscribe"],$text['footer']);
-  $html["footer"] = eregi_replace("\[UNSUBSCRIBE\]",$html["unsubscribe"],$html['footer']);
   $text["footer"] = eregi_replace("\[SUBSCRIBE\]",$text["subscribe"],$text['footer']);
   $html["footer"] = eregi_replace("\[SUBSCRIBE\]",$html["subscribe"],$html['footer']);
   $text["footer"] = eregi_replace("\[PREFERENCES\]",$text["preferences"],$text["footer"]);
@@ -242,9 +278,18 @@ function sendEmail ($messageid,$email,$hash,$htmlpref = 0,$rssitems = array(),$f
   $text["footer"] = eregi_replace("\[FORWARD\]",$text["forward"],$text["footer"]);
   $html["footer"] = eregi_replace("\[FORWARD\]",$html["forward"],$html["footer"]);
   $html["footer"] = eregi_replace("\[FORWARDFORM\]",$html["forwardform"],$html["footer"]);
+  $text["footer"] = eregi_replace("\[BLACKLIST\]",$text["blacklist"],$text['footer']);
+  $html["footer"] = eregi_replace("\[BLACKLIST\]",$html["blacklist"],$html['footer']);
   if (sizeof($forwardedby) && isset($forwardedby['email'])) {
+    $htmlmessage    = eregi_replace("\[FORWARDEDBY]",$forwardedby["email"],$htmlmessage);
+    $textmessage    = eregi_replace("\[FORWARDEDBY]",$forwardedby["email"],$textmessage);
     $html["footer"] = eregi_replace("\[FORWARDEDBY]",$forwardedby["email"],$html["footer"]);
     $text["footer"] = eregi_replace("\[FORWARDEDBY]",$forwardedby["email"],$text["footer"]);
+    $text["footer"] = eregi_replace("\[UNSUBSCRIBE\]",$text["blacklist"],$text['footer']);
+    $html["footer"] = eregi_replace("\[UNSUBSCRIBE\]",$html["blacklist"],$html['footer']);
+  } else {
+    $text["footer"] = eregi_replace("\[UNSUBSCRIBE\]",$text["unsubscribe"],$text['footer']);
+    $html["footer"] = eregi_replace("\[UNSUBSCRIBE\]",$html["unsubscribe"],$html['footer']);
   }
 
   $html["footer"] = '<div class="emailfooter">'.nl2br($html["footer"]).'</div>';
@@ -256,7 +301,11 @@ function sendEmail ($messageid,$email,$hash,$htmlpref = 0,$rssitems = array(),$f
   if (eregi("\[SIGNATURE\]",$htmlmessage))
     $htmlmessage = eregi_replace("\[SIGNATURE\]",$html["signature"],$htmlmessage);
   elseif ($html["signature"])
-    $htmlmessage .= '<br />'.$html["signature"];
+# BUGFIX 0015303, 2/2
+//    $htmlmessage .= '<br />'.$html["signature"];
+      $htmlmessage = addHTMLFooter($htmlmessage, '
+'. $html["signature"]);
+# END BUGFIX 0015303, 2/2
   if (eregi("\[FOOTER\]",$textmessage))
     $textmessage = eregi_replace("\[FOOTER\]",$text["footer"],$textmessage);
   else
@@ -327,7 +376,7 @@ function sendEmail ($messageid,$email,$hash,$htmlpref = 0,$rssitems = array(),$f
       }
     }
   }
-
+  
   $destinationemail = '';
   if (is_array($user_att_values)) {
     foreach ($user_att_values as $att_name => $att_value) {
@@ -505,6 +554,12 @@ if (0) {
     $textmessage = ereg_replace("\[LISTS\]",$lists_text,$textmessage);
   }
 
+  #0011996: forward to friend - personal message
+  if (FORWARD_PERSONAL_NOTE_SIZE && $hash = 'forwarded' && !empty($forwardedby['personalNote']) ) {
+    $htmlmessage =  nl2br($forwardedby['personalNote']) . '<br/>' .  $htmlmessage;
+    $textmessage = $forwardedby['personalNote'] . "\n" . $textmessage;
+  }
+  
   ## remove any existing placeholders
   $htmlmessage = eregi_replace("\[[A-Z\. ]+\]","",$htmlmessage);
   $textmessage = eregi_replace("\[[A-Z\. ]+\]","",$textmessage);
@@ -549,6 +604,9 @@ if (0) {
     ));
   } else {
     $mail = new PHPlistMailer($messageid,$destinationemail);
+    if ($forwardedby) {
+      $mail->add_timestamp();
+    }
     #$mail->IsSMTP();
   }
 
@@ -595,6 +653,8 @@ if (0) {
         if (ENABLE_RSS && sizeof($rssitems))
           updateRSSStats($rssitems,"ashtml");
       #  dbg("Adding HTML ".$cached[$messageid]["templateid"]);
+      ## wrap it: http://mantis.phplist.com/view.php?id=15528
+        $htmlmessage = wordwrap($htmlmessage, 60, "\r\n");
         $mail->add_html($htmlmessage,$textmessage,$cached[$messageid]["templateid"]);
         addAttachments($messageid,$mail,"HTML");
       } else {
@@ -782,9 +842,10 @@ function addAttachments($msgid,&$mail,$type) {
             sendMail(getConfig("report_address"),"Mail list error",$msg,"");
           }
            break;
+
          case "text":
           $viewurl = $GLOBALS["scheme"]."://".$website.$GLOBALS["pageroot"].'/dl.php?id='.$att["id"];
-          $mail->append_text($att["description"]."\n".$GLOBALS["strLocation"].": ".$viewurl);
+          $mail->append_text($att["description"]."\n".$GLOBALS["strLocation"].": ".$viewurl."\n");
           break;
       }
     }
@@ -952,7 +1013,7 @@ function stripHTML($text) {
 
 #  $text = preg_replace("/<a href=\"(.*?)\"[^>]*>(.*?)<\/a>/is","[URLTEXT]\\2[/URLTEXT][LINK]\\1[/LINK]",$text,100);
 
-  $text = preg_replace("/<a.*href=[\"\'](.*)[\"\'][^>]*>(.*)<\/a>/Umis","[URLTEXT]\\2[ENDURLTEXT][LINK]\\1[ENDLINK]\n",$text);
+  $text = preg_replace("/<a[^>]*href=[\"\'](.*)[\"\'][^>]*>(.*)<\/a>/Umis","[URLTEXT]\\2[ENDURLTEXT][LINK]\\1[ENDLINK]\n",$text);
 
   $text = preg_replace("/<b>(.*?)<\/b\s*>/is","*\\1*",$text);
   $text = preg_replace("/<h[\d]>(.*?)<\/h[\d]\s*>/is","**\\1**\n",$text);
