@@ -1,7 +1,7 @@
 <?php
 require_once dirname(__FILE__).'/accesscheck.php';
 
-define("STRUCTUREVERSION","2.10.5");
+define("STRUCTUREVERSION","2.10.14");
 
 $DBstruct = array( # order of tables is essential for smooth upgrade
     "attribute" => array ( # attributes of a user or a message
@@ -108,8 +108,8 @@ $DBstruct = array( # order of tables is essential for smooth upgrade
         "fromfield" => array("varchar(255) not null default ''","from"),
         "tofield" => array("varchar(255) not null default ''","tofield"),
         "replyto" => array("varchar(255) not null default ''","reply-to"),
-        "message" => array("Text","Message"),
-        "textmessage" => array("Text","Text version of Message"),
+        "message" => array("mediumtext","Message"),
+        "textmessage" => array("mediumtext","Text version of Message"),
         "footer" => array("text","Footer for a message"),
         "entered" => array("datetime","Entered"),
         "modified" => array("timestamp", "Modified"),
@@ -239,7 +239,8 @@ $DBstruct = array( # order of tables is essential for smooth upgrade
         "data" => array("blob","The bounce"),
         "status" => array("varchar(255)","Status of this bounce"),
         "comment" => array("text","System Comment"),
-        "index_1" => array("dateindex (date)","")
+        "index_1" => array("dateindex (date)",""),
+        "index_2" => array("statusindex (status(10))",""),
     ),
     "user_message_bounce" => array( # bounce. We can have one usermessage bounce multiple times
         "id" => array("integer not null primary key auto_increment","ID"),
@@ -404,6 +405,13 @@ $DBstruct = array( # order of tables is essential for smooth upgrade
         "bounce" => array("integer not null","Related bounce"),
         "primary key" => array("(regex,bounce)",""),
       ),
+      "admintoken" => array(
+        "id" => array("integer not null primary key auto_increment","ID"),
+        "adminid" => array("integer not null","adminid"),
+        "value" => array('varchar(255)',''),
+        "entered" => array('integer not null',''),
+        "expires" => array('datetime not null',''),
+      ),
 /*    "translation" => array(
       "id" => array("integer not null primary key auto_increment",""),
       "translator" => array("varchar(255)","Name of translator"),
