@@ -2,12 +2,14 @@
 
 ob_start();
 $er = error_reporting(0); 
+require_once dirname(__FILE__) .'/admin/commonlib/lib/unregister_globals.php';
 require_once dirname(__FILE__) .'/admin/commonlib/lib/magic_quotes.php';
 require_once dirname(__FILE__).'/admin/init.php';
 ## none of our parameters can contain html for now
 $_GET = removeXss($_GET);
 $_POST = removeXss($_POST);
 $_REQUEST = removeXss($_REQUEST);
+$_SERVER = removeXss($_SERVER);
 
 if (isset($_SERVER["ConfigFile"]) && is_file($_SERVER["ConfigFile"])) {
 #  print '<!-- using '.$_SERVER["ConfigFile"].'-->'."\n";
@@ -25,16 +27,19 @@ if (isset($_SERVER["ConfigFile"]) && is_file($_SERVER["ConfigFile"])) {
 if (0) {#isset($GLOBALS["developer_email"]) && $GLOBALS['show_dev_errors']) {
   error_reporting(E_ALL);
 } else {
-  if (isset($error_level)) {
-    error_reporting($error_level);
-  } else {
-    error_reporting($er);
-  }
+  error_reporting(0);
 }
 
 require_once dirname(__FILE__).'/admin/'.$GLOBALS["database_module"];
+
+# load default english and language
 require_once dirname(__FILE__)."/texts/english.inc";
 include_once dirname(__FILE__)."/texts/".$GLOBALS["language_module"];
+# Allow customisation per installation
+if (is_file($_SERVER['DOCUMENT_ROOT'].'/'.$GLOBALS["language_module"])) {
+  include_once $_SERVER['DOCUMENT_ROOT'].'/'.$GLOBALS["language_module"];
+}
+
 require_once dirname(__FILE__)."/admin/defaultconfig.inc";
 require_once dirname(__FILE__).'/admin/connect.php';
 include_once dirname(__FILE__)."/admin/languages.php";
@@ -72,6 +77,9 @@ if (isset($_GET['id'])) {
 // What is uid
 // What is userid
 // Why is there GET(id) and REQUEST(id)?
+$userid = "";
+$userpassword = "";
+$emailcheck = "";
 
 if (isset($_GET['uid']) && $_GET["uid"]) {
   $req = Sql_Fetch_Row_Query(sprintf('select subscribepage,id,password,email from %s where uniqid = "%s"',
@@ -80,20 +88,21 @@ if (isset($_GET['uid']) && $_GET["uid"]) {
   $userid = $req[1];
   $userpassword = $req[2];
   $emailcheck = $req[3];
-} elseif (isset($_GET["email"])) {
-  $req = Sql_Fetch_Row_Query(sprintf('select subscribepage,id,password,email from %s where email = "%s"',
-    $tables["user"],$_GET["email"]));
-  $id = $req[0];
-  $userid = $req[1];
-  $userpassword = $req[2];
-  $emailcheck = $req[3];
-} elseif (isset($_REQUEST["unsubscribeemail"])) {
-  $req = Sql_Fetch_Row_Query(sprintf('select subscribepage,id,password,email from %s where email = "%s"',
-    $tables["user"],$_REQUEST["unsubscribeemail"]));
-  $id = $req[0];
-  $userid = $req[1];
-  $userpassword = $req[2];
-  $emailcheck = $req[3];
+} elseif ($_GET['p'] == 'unsubscribe' || $_GET['p'] == 'blacklist' || $_GET['p'] == 'subscribe') {
+  if (isset($_GET["email"]) && validateEmail($_GET['email'])) {
+    $req = Sql_Fetch_Row_Query(sprintf('select subscribepage,id,password,email from %s where email = "%s"',
+      $tables["user"],$_GET["email"]));
+    $id = $req[0];
+    $userid = $req[1];
+    $userpassword = $req[2];
+    $emailcheck = $req[3];
+  } elseif (isset($_REQUEST["unsubscribeemail"]) && validateEmail($_REQUEST['unsubscribeemail'])) {
+    $req = Sql_Fetch_Row_Query(sprintf('select subscribepage,id,password,email from %s where email = "%s"',
+      $tables["user"],$_REQUEST["unsubscribeemail"]));
+    $id = $req[0];
+    $userid = $req[1];
+    $userpassword = $req[2];
+    $emailcheck = $req[3];
 /*
 } elseif ($_SESSION["userloggedin"] && $_SESSION["userid"]) {
   $req = Sql_Fetch_Row_Query(sprintf('select subscribepage,id,password,email from %s where id = %d',
@@ -103,11 +112,8 @@ if (isset($_GET['uid']) && $_GET["uid"]) {
   $userpassword = $req[2];
   $emailcheck = $req[3];
 */
-} else {
-  $userid = "";
-  $userpassword = "";
-  $emailcheck = "";
-}
+  }
+} 
 
 if (isset($_REQUEST['id']) && $_REQUEST["id"]){
   $id = sprintf('%d',$_REQUEST["id"]);
@@ -197,6 +203,15 @@ if ($login_required && empty($_SESSION["userloggedin"]) && !$canlogin) {
   print LoginPage($id,$userid,$emailcheck,$msg);
 } elseif (isset($_GET['p']) && preg_match("/(\w+)/",$_GET["p"],$regs)) {
   if ($id) {
+    $data = PageData($id);
+    if (isset($data['language_file']) && is_file(dirname(__FILE__).'/texts/'.basename($data['language_file']))) {
+      @include dirname(__FILE__).'/texts/'.basename($data['language_file']);
+      # Allow customisation per installation
+      if (is_file($_SERVER['DOCUMENT_ROOT'].'/'.basename($data['language_file']))) {
+        include_once $_SERVER['DOCUMENT_ROOT'].'/'.basename($data['language_file']);
+      }
+    }
+    
     switch ($_GET["p"]) {
       case "subscribe":
         $success = require "admin/subscribelib2.php";
@@ -222,6 +237,8 @@ if ($login_required && empty($_SESSION["userloggedin"]) && !$canlogin) {
       case "confirm":
          print ConfirmPage($id);
         break;
+      #0013076: Blacklisting posibility for unknown users
+      case "blacklist":
       case "unsubscribe":
         print UnsubscribePage($id);
         break;
@@ -233,8 +250,8 @@ if ($login_required && empty($_SESSION["userloggedin"]) && !$canlogin) {
   }
 } else {
   if ($id) $data = PageData($id);
-  if (isset($data['language_file']) && is_file(dirname(__FILE__).'/texts/'.$data['language_file'])) {
-    @include dirname(__FILE__).'/texts/'.$data['language_file'];
+  if (isset($data['language_file']) && is_file(dirname(__FILE__).'/texts/'.basename($data['language_file']))) {
+    @include dirname(__FILE__).'/texts/'.basename($data['language_file']);
   }
   print '<title>'.$GLOBALS["strSubscribeTitle"].'</title>';
   print $data["header"];
@@ -256,9 +273,6 @@ if ($login_required && empty($_SESSION["userloggedin"]) && !$canlogin) {
 
 function LoginPage($id,$userid,$email = "",$msg = "") {
   $data = PageData($id);
-  if (isset($data['language_file']) && is_file(dirname(__FILE__).'/texts/'.$data['language_file'])) {
-    @include dirname(__FILE__).'/texts/'.$data['language_file'];
-  }
   list($attributes,$attributedata) = PageAttributes($data);
   $html = '<title>'.$GLOBALS["strLoginTitle"].'</title>';
   $html .= $data["header"];
@@ -274,7 +288,7 @@ function LoginPage($id,$userid,$email = "",$msg = "") {
   $html .= formStart('name="loginform"');
   $html .= '<table border=0>';
   $html .= '<tr><td>'.$GLOBALS["strEmail"].'</td><td><input type=text name="email" value="'.$email.'" size="30"></td></tr>';
-  $html .= '<tr><td>'.$GLOBALS["strPassword"].'</td><td><input type=password name="password" value="'.$_POST["password"].'" size="30"></td></tr>';
+  $html .= '<tr><td>'.$GLOBALS["strPassword"].'</td><td><input type="password" name="password" value="'.$_POST["password"].'" size="30"></td></tr>';
   $html .= '</table>';
    $html .= '<p><input type=submit name="login" value="'.$GLOBALS["strLogin"].'"></p>';
   if (ENCRYPTPASSWORD) {
@@ -290,10 +304,7 @@ function LoginPage($id,$userid,$email = "",$msg = "") {
 }
 
 function sendPersonalLocationPage($id) {
-  $data = PageData($id);
-  if (isset($data['language_file']) && is_file(dirname(__FILE__).'/texts/'.$data['language_file'])) {
-    @include dirname(__FILE__).'/texts/'.$data['language_file'];
-  }
+  global $data ;
   list($attributes,$attributedata) = PageAttributes($data);
   $html = '<title>'.$GLOBALS["strPreferencesTitle"].'</title>';
   $html .= $data["header"];
@@ -319,10 +330,7 @@ function sendPersonalLocationPage($id) {
 }
 
 function preferencesPage($id,$userid) {
-  $data = PageData($id);
-  if (isset($data['language_file']) && is_file(dirname(__FILE__).'/texts/'.$data['language_file'])) {
-    @include dirname(__FILE__).'/texts/'.$data['language_file'];
-  }
+  global $data;
   list($attributes,$attributedata) = PageAttributes($data);
   $selected_lists = explode(',',$data["lists"]);
   $html = '<title>'.$GLOBALS["strPreferencesTitle"].'</title>';
@@ -394,10 +402,7 @@ function compareEmail()
 }
 
 function subscribePage($id) {
-  $data = PageData($id);
-  if (isset($data['language_file']) && is_file(dirname(__FILE__).'/texts/'.$data['language_file'])) {
-    @include dirname(__FILE__).'/texts/'.$data['language_file'];
-  }
+  global $data;  
   list($attributes,$attributedata) = PageAttributes($data);
   $selected_lists = explode(',',$data["lists"]);
   $html = '<title>'.$GLOBALS["strSubscribeTitle"].'</title>';
@@ -521,7 +526,7 @@ function checkGroup(name,value) {
 }
 
 function confirmPage($id) {
-  global $tables,$envelope;
+  global $data, $tables, $envelope;
   if (!$_GET["uid"]) {
     FileNotFound();
   }
@@ -548,12 +553,10 @@ function confirmPage($id) {
     }
     addUserHistory($userdata["email"],"Confirmation","Lists: $lists");
 
-    $spage = $userdata["subscribepage"];
-
-    $confirmationmessage = ereg_replace('\[LISTS\]', $lists, getUserConfig("confirmationmessage:$spage",$userdata["id"]));
+    $confirmationmessage = ereg_replace('\[LISTS\]', $lists, getUserConfig("confirmationmessage:$id",$userdata["id"]));
 
     if (!TEST) {
-      sendMail($userdata["email"], getConfig("confirmationsubject:$spage"), $confirmationmessage,system_messageheaders(),$envelope);
+      sendMail($userdata["email"], getConfig("confirmationsubject:$id"), $confirmationmessage,system_messageheaders(),$envelope);
       $adminmessage = $userdata["email"] . " has confirmed their subscription";
       if ($blacklisted) {
         $adminmessage .= "\nUser has been removed from blacklist";
@@ -567,10 +570,6 @@ function confirmPage($id) {
     $html .= 'Error: '.$GLOBALS["strUserNotFound"];
     $info = $GLOBALS["strConfirmFailInfo"];
   }
-  $data = PageData($id);
-  if (isset($data['language_file']) && is_file(dirname(__FILE__).'/texts/'.$data['language_file'])) {
-    @include dirname(__FILE__).'/texts/'.$data['language_file'];
-  }
 
   $res = '<title>'.$GLOBALS["strConfirmTitle"].'</title>';
   $res .= $data["header"];
@@ -582,13 +581,10 @@ function confirmPage($id) {
 }
 
 function unsubscribePage($id) {
-  $pagedata = pageData($id);
-  if (isset($pagedata['language_file']) && is_file(dirname(__FILE__).'/texts/'.$pagedata['language_file'])) {
-    @include dirname(__FILE__).'/texts/'.$pagedata['language_file'];
-  }
-  global $tables;
-  $res .= '<title>'.$GLOBALS["strUnsubscribeTitle"].'</title>';
-  $res = $pagedata["header"];
+  global $data, $tables;
+  $res = '<title>'.$GLOBALS["strUnsubscribeTitle"].'</title>'."\n";  
+  $res .= $data["header"];
+
   if (isset($_GET["uid"])) {
     $req = Sql_Query("select * from $tables[user] where uniqid = \"".$_GET["uid"]."\"");
     $userdata = Sql_Fetch_Array($req);
@@ -596,22 +592,61 @@ function unsubscribePage($id) {
     if (UNSUBSCRIBE_JUMPOFF) {
       $_POST["unsubscribe"] = 1;
       $_POST["email"] = $email;
+      $_REQUEST['unsubscribeemail'] = $email;
       $_POST["unsubscribereason"] = '"Jump off" set, reason not requested';
     }
+  } else {
+    if (isset($_REQUEST['unsubscribeemail'])) {
+       if (UNSUBSCRIBE_JUMPOFF) {
+          $_POST["unsubscribe"] = 1;
+          $_POST["unsubscribereason"] = '"Jump off" set, reason not requested';
+       }
+       $email = $_REQUEST['unsubscribeemail'];
+    } else {
+       if (isset($_REQUEST['email'])) {
+          if (UNSUBSCRIBE_JUMPOFF) {
+             $_POST["unsubscribe"] = 1;
+             $_POST["unsubscribereason"] = '"Jump off" set, reason not requested';
+          }
+          $email = $_REQUEST['email'];
+       }
+    }
+
+    
+    #0013076: Blacklisting posibility for unknown users
+    # Set flag for blacklisting 
+    $blacklist = $_GET['p'] == 'blacklist';
+    
+    # only proceed when user has confirm the form 
+    if ($blacklist && is_email($_REQUEST['unsubscribeemail']) ) {
+      $_POST["unsubscribe"] = 1;
+      $_POST["unsubscribereason"] = 'Forwarded receiver requested blacklist';
+    }
   }
 
-  if (isset($_POST["unsubscribe"]) && (isset($_POST["email"]) || isset($_POST["unsubscribeemail"])) && isset($_POST["unsubscribereason"])) {
-    if (isset($_POST["email"])) {
-      $email = trim($_POST["email"]);
-    } else {
-      $email = $_POST["unsubscribeemail"];
+  $unsubscribeemail = (isset($_REQUEST['unsubscribeemail']))?$_REQUEST['unsubscribeemail']:$_REQUEST['email'];
+  
+  if ( is_email($unsubscribeemail) && isset($_POST['unsubscribe']) && (isset($_REQUEST['email']) || isset($_REQUEST['unsubscribeemail'])) && isset($_POST['unsubscribereason'])) {
+
+    #0013076: Blacklisting posibility for unknown users
+    if ( !$blacklist ) {
+      // It would be better to do this above, where the email is set for the other cases.
+      // But to prevent vulnaribilities let's keep it here for now. [bas]
+      $query = Sql_Fetch_Row_Query("select id,email from {$tables["user"]} where email = \"$email\"");
+      $userid = $query[0];
+      $email = $query[1];
     }
-    $query = Sql_Fetch_Row_Query("select id,email from {$tables["user"]} where email = \"$email\"");
-    $userid = $query[0];
-    $email = $query[1];
+
     if (!$userid) {
-      $res .= 'Error: '.$GLOBALS["strUserNotFound"];
-      logEvent("Request to unsubscribe non-existent user: ".substr($_POST["email"],0,150));
+
+      #0013076: Blacklisting posibility for unknown users
+      if ( $blacklist ) {
+        addUserToBlacklist($email,$_POST['unsubscribereason']);
+        addSubscriberStatistics('forwardblacklist',1);
+      } else {       
+        $res .= 'Error: '.$GLOBALS["strUserNotFound"];
+        logEvent("Request to unsubscribe non-existent user: ".substr($_POST["email"],0,150));
+      }
     } else {
       $result = Sql_query("delete from {$tables["listuser"]} where userid = \"$userid\"");
       $lists = "  * ".$GLOBALS["strAllMailinglists"]."\n";
@@ -628,10 +663,14 @@ function unsubscribePage($id) {
 
     if ($userid)
       $res .= '<h1>'.$GLOBALS["strUnsubscribeDone"] ."</h1><P>";
+
+    #0013076: Blacklisting posibility for unknown users
+    if ($blacklist)
+      $res .= '<h1>'.$GLOBALS["strYouAreBlacklisted"] ."</h1><P>";
     $res .= $GLOBALS["PoweredBy"].'</p>';
-    $res .= $pagedata["footer"];
+    $res .= $data["footer"];
     return $res;
-  } elseif (isset($_POST["unsubscribe"]) && !$_POST["unsubscribeemail"]) {
+  } elseif ( isset($_POST["unsubscribe"]) &&  !is_email($_REQUEST['unsubscribeemail']))  {
     $msg = '<span class="error">'.$GLOBALS["strEnterEmail"]."</span><br>";
   } elseif (!empty($_GET["email"])) {
     $email = trim($_GET["email"]);
@@ -657,7 +696,7 @@ function unsubscribePage($id) {
   if (!$email) {
     $res .= "<input type=submit name=unsubscribe value=\"$GLOBALS[strContinue]\"></form>\n";
     $res .= $GLOBALS["PoweredBy"];
-    $res .= $pagedata["footer"];
+    $res .= $data["footer"];
     return $res;
   }
 
@@ -680,113 +719,236 @@ function unsubscribePage($id) {
   $finaltext = eregi_replace('\[preferencesurl\]',$pref_url.$sep.'uid='.$hash,$finaltext);
 
   if (!$some) {
-    $res .= "<b>".$GLOBALS["strNoListsFound"]."</b></ul>";
-    $res .= '<p><input type=submit value="'.$GLOBALS["strResubmit"].'">';
+    #0013076: Blacklisting posibility for unknown users
+    if (!$blacklist) {
+      $res .= "<b>".$GLOBALS["strNoListsFound"]."</b></ul>";
+    }
+    $res .= '<p><input type=submit value="'.$GLOBALS["strUnsubscribe"].'">';
   } else {
-    list($r,$c) = explode(",",getConfig("textarea_dimensions"));
-    if (!$r) $r = 5;
-    if (!$c) $c = 65;
-    $res .= $GLOBALS["strUnsubscribeRequestForReason"];
-    $res .= sprintf('<br/><textarea name="unsubscribereason" cols="%d" rows="%d" wrap="virtual"></textarea>',$c,$r).'
-
-    '.$finaltext.'
-
-    <p><input type=submit name="unsubscribe" value="'.$GLOBALS["strUnsubscribe"].'"></p>';
+    if ($blacklist) {
+      $res .= $GLOBALS["strExplainBlacklist"];
+    } elseif (!UNSUBSCRIBE_JUMPOFF) {      
+      list($r,$c) = explode(",",getConfig("textarea_dimensions"));
+      if (!$r) $r = 5;
+      if (!$c) $c = 65;
+      $res .= $GLOBALS["strUnsubscribeRequestForReason"];
+      $res .= sprintf('<br/><textarea name="unsubscribereason" cols="%d" rows="%d" wrap="virtual"></textarea>',$c,$r) . $finaltext;
+    }
+    $res .= '<p><input type=submit name="unsubscribe" value="'.$GLOBALS["strUnsubscribe"].'"></p>';
   }
-
+  $res .= '</form>';
   $res .= '<p>'.$GLOBALS["PoweredBy"].'</p>';
-  $res .= $pagedata["footer"];
+  $res .= $data["footer"];
   return $res;
 }
 
+########################################
+if (!function_exists("htmlspecialchars_decode")) {
+   function htmlspecialchars_decode($string, $quote_style = ENT_COMPAT) {
+       return strtr($string, array_flip(get_html_translation_table(HTML_SPECIALCHARS, $quote_style)));
+   }
+}
 function forwardPage($id) {
-  global $tables,$envelope;
-  $html = '';
+  global $data, $tables, $envelope;
+  $ok = true;
   $subtitle = '';
-  if (!isset($_GET["uid"]) || !$_GET['uid'])
+  $info = '';
+  $html = '';
+  $form = '';
+  
+  ## Check requirements
+  
+  # user
+  if (!isset($_REQUEST["uid"]) || !$_REQUEST['uid'])
     FileNotFound();
 
+  $firstpage = 1; ## is this the initial page or a followup
+  
+  # forward addresses
   $forwardemail = '';
-  if (isset($_GET['email'])) {
-    $forwardemail = $_GET['email'];
+  if (isset($_REQUEST['email']) && !empty($_REQUEST['email'])) {
+    $firstpage = 0;
+    $forwardPeriodCount = Sql_Fetch_Array_Query(sprintf('select count(user) from %s where date_add(time,interval %s) >= now() and user = %d and status ="sent" ',
+      $tables['user_message_forward'],FORWARD_EMAIL_PERIOD, $userdata['id']));
+    $forwardemail = stripslashes($_REQUEST['email']);
+    $emails = explode("\n",$forwardemail);
+    $emails = trimArray($emails);
+    $forwardemail = implode("\n", $emails);
+    #0011860: forward to friend, multiple emails 
+    $emailCount = $forwardPeriodCount[0];
+    foreach ( $emails as $index => $email) {
+      $emails[$index] = trim($email);
+      if( is_email($email) ) {
+        $emailCount++;
+      } else {
+        $info .= sprintf('<BR />' . $GLOBALS['strForwardInvalidEmail'], $email);
+        $ok = false;
+      }
+    }
+    if ( $emailCount > FORWARD_EMAIL_COUNT ) {
+      $info.= '<BR />' . $GLOBALS["strForwardCountReached"];
+      $ok = false;
+    } 
+  } else {  
+    $ok = false;
   }
+  
+  # message
   $mid = 0;
-  if (isset($_GET['mid'])) {
-    $mid = sprintf('%d',$_GET['mid']);
+  if (isset($_REQUEST['mid'])) {
+    $mid = sprintf('%d',$_REQUEST['mid']);
     $req = Sql_Query(sprintf('select * from %s where id = %d',$tables["message"],$mid));
     $messagedata = Sql_Fetch_Array($req);
     $mid = $messagedata['id'];
     if ($mid) {
       $subtitle = $GLOBALS['strForwardSubtitle'].' '.stripslashes($messagedata['subject']);
     }
-  }
-  $req = Sql_Query("select * from {$tables["user"]} where uniqid = \"".$_GET["uid"]."\"");
-  $userdata = Sql_Fetch_Array($req);
+  } #mid set
 
+  ## get userdata
+  $req = Sql_Query("select * from {$tables["user"]} where uniqid = \"".$_REQUEST["uid"]."\"");
+  $userdata = Sql_Fetch_Array($req);
   $req = Sql_Query(sprintf('select * from %s where email = "%s"',$tables["user"],$forwardemail));
   $forwarduserdata = Sql_Fetch_Array($req);
-
-  if ($userdata["id"] && $mid) {
-    if (!is_email($forwardemail)) {
-      $info = $GLOBALS['strForwardEnterEmail'];
-      $html .= '<form method="get">';
-      $html .= sprintf('<input type=hidden name="mid" value="%d">',$mid);
-      $html .= sprintf('<input type=hidden name="id" value="%d">',$id);
-      $html .= sprintf('<input type=hidden name="uid" value="%s">',$userdata['uniqid']);
-      $html .= sprintf('<input type=hidden name="p" value="forward">');
-      $html .= sprintf('<input type=text name="email" value="%s" size=35 class="attributeinput">',$forwardemail);
-      $html .= sprintf('<input type=submit value="%s"></form>',$GLOBALS['strContinue']);
-    } else {
-      # check whether the email to forward exists and whether they have received the message
-      if ($forwarduserdata['id']) {
-        $sent = Sql_Fetch_Row_Query(sprintf('select entered from %s where userid = %d and messageid = %d',
-          $tables['usermessage'],$forwarduserdata['id'],$mid));
-        # however even if that's the case, we don't want to reveal this information
+  
+  #0011996: forward to friend - personal message
+  # text cannot be longer than max, to prevent very long text with only linefeeds total cannot be longer than twice max
+  if (FORWARD_PERSONAL_NOTE_SIZE && isset($_REQUEST['personalNote']) ) {
+      if (strlen(strip_newlines($_REQUEST['personalNote'])) > FORWARD_PERSONAL_NOTE_SIZE || strlen($_REQUEST['personalNote']) > FORWARD_PERSONAL_NOTE_SIZE  * 2  ) {
+        $info .= '<BR />' . $GLOBALS['strForwardNoteLimitReached'];            
+        $ok = false;
       }
-
-      $done = Sql_Fetch_Array_Query(sprintf('select user,status,time from %s where forward = "%s" and message = %d',
-        $tables['user_message_forward'],$forwardemail,$mid));
-      if ($done['status'] === 'sent') {
-        $info = $GLOBALS['strForwardAlreadyDone'];
+    $personalNote = strip_tags(htmlspecialchars_decode(stripslashes($_REQUEST['personalNote'])));
+    $userdata['personalNote'] = $personalNote;
+  }
+    
+  if ($userdata["id"] && $mid) {
+    if ($ok && count($emails)) { ## All is well, send it 
+      require 'admin/sendemaillib.php';
+      
+      #0013845 Lead Ref Scheme
+      if (FORWARD_FRIEND_COUNT_ATTRIBUTE) {
+        $iCountFriends = getAttributeIDbyName(FORWARD_FRIEND_COUNT_ATTRIBUTE);
       } else {
-        if (!TEST) {
-          # forward the message
-          require 'admin/sendemaillib.php';
-          # sendEmail will take care of blacklisting
-          if (sendEmail($mid,$forwardemail,'forwarded',$userdata['htmlemail'],array(),$userdata)) {
-            $info = $GLOBALS["strForwardSuccessInfo"];
-            sendAdminCopy("Message Forwarded",$userdata["email"] . " has forwarded a message $mid to $forwardemail");
-            Sql_Query(sprintf('insert into %s (user,message,forward,status,time)
-              values(%d,%d,"%s","sent",now())',
-              $tables['user_message_forward'],$userdata['id'],$mid,$forwardemail));
-          } else {
-            $info = $GLOBALS["strForwardFailInfo"];
-            sendAdminCopy("Message Forwarded",$userdata["email"] . " tried forwarding a message $mid to $forwardemail but failed");
-            Sql_Query(sprintf('insert into %s (user,message,forward,status,time)
-              values(%d,%d,"%s","failed",now())',
-              $tables['user_message_forward'],$userdata['id'],$mid,$forwardemail));
+        $iCountFriends = 0;
+      }
+      if($iCountFriends) {
+        $nFriends = intval(UserAttributeValue($userdata['id'], $iCountFriends));
+      }
+      
+      #0011860: forward to friend, multiple emails 
+      foreach ( $emails as $index => $email) {
+        #0011860: forward to friend, multiple emails 
+        $done = Sql_Fetch_Array_Query(sprintf('select user,status,time from %s where forward = "%s" and message = %d',
+        $tables['user_message_forward'],$email,$mid));
+        $info .= '<BR />' . $email . ': ';
+        if ($done['status'] === 'sent') {
+          $info .= $GLOBALS['strForwardAlreadyDone'];
+        } elseif (isBlackListed($email)) {
+          $info .= $GLOBALS['strForwardBlacklistedEmail'];
+        } else {
+          if (!TEST) {
+            # forward the message
+            # sendEmail will take care of blacklisting
+            if (sendEmail($mid,$email,'forwarded',$userdata['htmlemail'],array(),$userdata)) {
+              $info .= $GLOBALS["strForwardSuccessInfo"];
+              sendAdminCopy("Message Forwarded",$userdata["email"] . " has forwarded a message $mid to $email");
+              Sql_Query(sprintf('insert into %s (user,message,forward,status,time)
+                 values(%d,%d,"%s","sent",now())',
+                $tables['user_message_forward'],$userdata['id'],$mid,$email));
+              if( $iCountFriends ) $nFriends++;
+            } else {
+              $info .= $GLOBALS["strForwardFailInfo"];
+              sendAdminCopy("Message Forwarded",$userdata["email"] . " tried forwarding a message $mid to $email but failed");
+              Sql_Query(sprintf('insert into %s (user,message,forward,status,time)
+                values(%d,%d,"%s","failed",now())',
+                $tables['user_message_forward'],$userdata['id'],$mid,$email));
+                $ok = false;
+            }
           }
         }
+      } # foreach friend
+      if( $iCountFriends ) {
+        saveUserAttribute($userdata['id'], $iCountFriends, 
+          array('name' => FORWARD_FRIEND_COUNT_ATTRIBUTE, 'value' => $nFriends));
       }
-
-    }
-
-  } else {
-    logEvent("Forward request from invalid user ID: ".substr($_GET["uid"],0,150));
-    $info = $GLOBALS["strForwardFailInfo"];
+    } #ok & emails
+        
+  } else { # no valid sender
+    logEvent("Forward request from invalid user ID: ".substr($_REQUEST["uid"],0,150));
+    $info .= '<BR />' . $GLOBALS["strForwardFailInfo"];
+    $ok = false;
   }
   $data = PageData($id);
-  if (isset($data['language_file']) && is_file(dirname(__FILE__).'/texts/'.$data['language_file'])) {
-    @include dirname(__FILE__).'/texts/'.$data['language_file'];
+  if (isset($data['language_file']) && is_file(dirname(__FILE__).'/texts/'.basename($data['language_file']))) {
+    @include dirname(__FILE__).'/texts/'.basename($data['language_file']);
   }
 
-  $res = '<title>'.$GLOBALS["strForwardTitle"].'</title>';
-  $res .= $data["header"];
-  $res .= '<h1>'.$subtitle.'</h1>';
-  $res .= '<h2>'.$info.'</h2>';
-  $res .= $html;
-  $res .= "<P>".$GLOBALS["PoweredBy"].'</p>';
-  $res .= $data["footer"];
+## BAS Multiple Forward
+  ## build response page
+  $form = '<form method="post" action="">';
+  $form .= sprintf('<input type=hidden name="mid" value="%d">',$mid);
+  $form .= sprintf('<input type=hidden name="id" value="%d">',$id);
+  $form .= sprintf('<input type=hidden name="uid" value="%s">',$userdata['uniqid']);
+  $form .= sprintf('<input type=hidden name="p" value="forward">');
+  if (!$ok) {
+    #0011860: forward to friend, multiple emails 
+    if (FORWARD_EMAIL_COUNT == 1) {
+      $form .= '<BR /><H2>' .$GLOBALS['strForwardEnterEmail'] . '</H2>';
+      $form .= sprintf('<input type=text name="email" value="%s" size=50 class="attributeinput">',$forwardemail);
+    } else {
+      $form .= '<BR /><H2>' .sprintf($GLOBALS['strForwardEnterEmails'], FORWARD_EMAIL_COUNT) . '</H2>';
+      $form .= sprintf('<textarea name="email" rows=10 cols=50 class="attributeinput">%s</textarea>', $forwardemail);
+    }
+
+    #0011996: forward to friend - personal message
+    if (FORWARD_PERSONAL_NOTE_SIZE ) {
+      $form .= sprintf('<h2>' . $GLOBALS['strForwardPersonalNote'] . '</H2>', FORWARD_PERSONAL_NOTE_SIZE);
+      $cols=50;
+      $rows=min(10,ceil(FORWARD_PERSONAL_NOTE_SIZE / 40));
+
+      $form .=sprintf('<BR/><textarea type=text name="personalNote" rows=%d cols=%d class="attributeinput">%s</textarea>', $rows, $cols, $personalNote);
+    }
+    $form .= sprintf('<br /><input type=submit value="%s"></form>',$GLOBALS['strContinue']);
+  }
+
+### END BAS
+
+### Michiel, remote response page
+
+  $remote_content = '';
+  if (preg_match("/\[URL:([^\s]+)\]/i",$messagedata['message'],$regs)) {
+    if (isset($regs[1]) && strlen($regs[1])) {
+      $url = $regs[1];
+      if (!preg_match('/^http/i',$url)) {
+        $url = 'http://'.$url;
+      }
+      $remote_content = fetchUrl($url);
+    }
+  }
+
+  if (!empty($remote_content) && preg_match('/\[FORWARDFORM\]/',$remote_content,$regs)) {
+    if ($firstpage) {
+      ## this is the initial page, not a follow up one.
+      $remote_content = str_replace($regs[0],$info.$form,$remote_content);
+    } else {
+      $remote_content = str_replace($regs[0],$info,$remote_content);
+    }
+    $res = $remote_content;
+  } else {
+    $res = '<title>'.$GLOBALS["strForwardTitle"].'</title>';
+    $res .= $data["header"];
+    $res .= '<h1>'.$subtitle.'</h1>';
+    if ($ok) {
+      $res .= '<h2>'.$info.'</h2>';
+    } else {
+      $res .= '<div class="missing">'.$info.'</div>';
+    }
+    $res .= $form;
+    $res .= "<P>".$GLOBALS["PoweredBy"].'</p>';
+    $res .= $data["footer"];
+  }
+### END MICHIEL
   return $res;
 }
 ?>
